@@ -4,13 +4,13 @@
 use std::collections::BTreeSet;
 use std::convert::TryInto;
 
-use actors_runtime::runtime::{ActorCode, Runtime};
-use actors_runtime::{
+use anyhow::anyhow;
+use ext::init;
+use fil_actors_runtime::runtime::{ActorCode, Runtime};
+use fil_actors_runtime::{
     actor_error, make_map_with_root_and_bitwidth, wasm_trampoline, ActorDowncast, ActorError,
     Multimap, CRON_ACTOR_ADDR, INIT_ACTOR_ADDR, REWARD_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
 };
-use anyhow::anyhow;
-use ext::init;
 use fvm_shared::actor::builtin::{Type, CALLER_TYPES_SIGNABLE};
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser::{BigIntDe, BigIntSer};
@@ -29,6 +29,9 @@ pub use self::policy::*;
 pub use self::state::*;
 pub use self::types::*;
 
+#[cfg(feature = "wasm")]
+pub const WASM_BINARY: &[u8] = include_bytes!(env!("WASM_BINARY"));
+
 wasm_trampoline!(Actor);
 
 #[doc(hidden)]
